@@ -22,6 +22,7 @@ import nwdiag
 import DiagramDraw
 import diagparser
 from blockdiag import utils
+from blockdiag.command import detectfont
 from builder import ScreenNodeBuilder
 
 
@@ -78,29 +79,14 @@ def parse_option():
     return options, args
 
 
-def detectfont(options):
-    fonts = options.font + \
-            ['c:/windows/fonts/VL-Gothic-Regular.ttf',  # for Windows
-             'c:/windows/fonts/msmincho.ttf',  # for Windows
-             '/usr/share/fonts/truetype/ipafont/ipagp.ttf',  # for Debian
-             '/usr/local/share/font-ipa/ipagp.otf',  # for FreeBSD
-             '/System/Library/Fonts/AppleGothic.ttf']  # for MaxOS
-
-    fontpath = None
-    for path in fonts:
-        if path and os.path.isfile(path):
-            fontpath = path
-            break
-
-    return fontpath
-
-
 def main():
     options, args = parse_option()
 
     infile = args[0]
     if options.filename:
         outfile = options.filename
+    elif infile == '-':
+        outfile = 'output.' + options.type.lower()
     else:
         outfile = re.sub('\..*', '', infile) + '.' + options.type.lower()
 
@@ -110,7 +96,12 @@ def main():
     fontpath = detectfont(options)
 
     try:
-        tree = diagparser.parse_file(infile)
+        if infile == '-':
+            import codecs
+            stream = codecs.getreader('utf-8')(sys.stdin)
+            tree = diagparser.parse_string(stream.read())
+        else:
+            tree = diagparser.parse_file(infile)
     except Exception, e:
         sys.stderr.write("ERROR: %s\n" % e)
         return
